@@ -13,6 +13,7 @@
 
 import os
 import argparse
+import pytz
 from schematics.types import StringType, URLType
 import dna.logging
 import dna.utils
@@ -78,12 +79,10 @@ class Context(object):
         self._validate(config)
 
         # From a human input (forex,4), setup a complete market structure
-        market = universe.Market()
-        market.parse_universe_description(config.pop('universe'))
-        # Remove holidays and other market closed periods
-        config['index'] = market.filter_open_days(config['index'])
+        market_ = universe.Market()
+        market_.parse_universe_description(config.pop('universe'))
 
-        return {'config': config, 'strategy': strategy, 'market': market}
+        return {'config': config, 'strategy': strategy, 'market': market_}
 
     def __exit__(self, type, value, traceback):
         pass
@@ -93,6 +92,9 @@ class Context(object):
         try:
             # Check if needed informations are here
             assert intuition.constants.CONFIG_SCHEMA.validate(config)
+            # Index Check
+            assert config['index'].size, 'No trading timeline'
+            assert (config['index'].tzinfo == pytz.utc), 'Invalid timezone'
         except Exception as error:
             raise InvalidConfiguration(config=config, reason=error)
 
