@@ -23,9 +23,7 @@ def clean_sid(sid):
 
 
 def apply_mapping(raw_row, mapping):
-    '''
-    Override this to hand craft conversion of row.
-    '''
+    ''' Override dict key names '''
     row = {target: mapping_func(raw_row[source_key])
            for target, (mapping_func, source_key)
            in mapping.fget().items()}
